@@ -5,8 +5,9 @@ import zipfile
 from enum import Enum
 import inspect
 from pathlib import Path
-from typing import List, Any
+from typing import List, Union
 from onnc.bench.core.model.model import Model
+from onnc.bench.core.dataset.dataset import Dataset
 # from typing import TYPE_CHECKING
 
 # if TYPE_CHECKING:
@@ -41,22 +42,14 @@ class Identifier(metaclass=IdentifierRegistry):
     FORMAT = ModelFormat.NON_SPECIFIED
 
     @classmethod
-    def is_me(cls, model: Any) -> bool:
+    def is_me(cls, model: Model) -> bool:
         pass
 
 
-def identifier_selector(model: Any) -> Identifier:
-    for identifier in Identifier.REGISTRY:
-        if identifier.is_me(model):
-            return identifier
-    raise NotImplementedError(f"Unable to identify {model.src}")
-
-
-def identify(model: Any) -> ModelFormat:
+def identify(model: Model) -> ModelFormat:
     for identifier in Identifier.REGISTRY:
         if identifier.is_me(model):
             return identifier.FORMAT
-
     raise NotImplementedError(f"Unable to identify {model.src}")
 
 
@@ -67,7 +60,7 @@ class H5(Identifier):
     FORMAT = ModelFormat.H5
 
     @classmethod
-    def is_me(cls, model: Any) -> bool:
+    def is_me(cls, model: Model) -> bool:
         if model.format == cls.FORMAT:
             return True
 
@@ -92,7 +85,7 @@ class ONNX(Identifier):
     FORMAT = ModelFormat.ONNX
 
     @classmethod
-    def is_me(cls, model: Any):
+    def is_me(cls, model: Model):
         if model.format == cls.FORMAT:
             return True
 
@@ -106,16 +99,17 @@ class ONNX(Identifier):
         if str(path).lower().endswith('.onnx'):
             return True
 
-        # Fixme
-        with open(path, 'rb') as f:
-            d = f.read(4)
-            return d[0] == 8 and d[2:4] in [
-                bytes.fromhex(x) for x in ['1207', '120B']
-            ]
+        import onnx
+        try:
+            onnx.checker.check_model(str(path))
+        except onnx.onnx_cpp2py_export.checker.ValidationError:
+            return False
+        return True
 
 
 class PTH(Identifier):
     """
+    Handle model serialized by torch.save
     Pth archives the model in zip format.
 
     This identifier determin if the input file is in zip format by magic
@@ -124,7 +118,7 @@ class PTH(Identifier):
     FORMAT = ModelFormat.PTH
 
     @classmethod
-    def is_me(cls, model: Any):
+    def is_me(cls, model: Model):
 
         if model.format == cls.FORMAT:
             return True
@@ -133,7 +127,7 @@ class PTH(Identifier):
             path = Path(model.src)
         else:
             path = model.src
-            
+
         if not (isinstance(path, Path) and path.exists() and path.is_file()):
             return False
 
@@ -161,7 +155,7 @@ class TorchTraced(Identifier):
     FORMAT = ModelFormat.TORCH_TRACED
 
     @classmethod
-    def is_me(cls, model: Any):
+    def is_me(cls, model: Model):
 
         if model.format == cls.FORMAT:
             return True
@@ -170,7 +164,7 @@ class TorchTraced(Identifier):
             path = Path(model.src)
         else:
             path = model.src
-            
+
         if not (isinstance(path, Path) and path.exists() and path.is_file()):
             return False
 
@@ -196,7 +190,7 @@ class PB(Identifier):
     FORMAT = ModelFormat.PB
 
     @classmethod
-    def is_me(cls, model: Any):
+    def is_me(cls, model: Model):
 
         if model.format == cls.FORMAT:
             return True
@@ -205,7 +199,7 @@ class PB(Identifier):
             path = Path(model.src)
         else:
             path = model.src
-            
+
         if not (isinstance(path, Path) and path.exists() and path.is_file()):
             return False
 
@@ -235,7 +229,7 @@ class TFLITE(Identifier):
     FORMAT = ModelFormat.TFLITE
 
     @classmethod
-    def is_me(cls, model: Any):
+    def is_me(cls, model: Model):
 
         if model.format == cls.FORMAT:
             return True
@@ -244,7 +238,6 @@ class TFLITE(Identifier):
             path = Path(model.src)
         else:
             path = model.src
-            
 
         if str(path).lower().endswith(".tflite"):
             return True
@@ -266,7 +259,7 @@ class SavedModel(Identifier):
     FORMAT = ModelFormat.SAVED_MODEL
 
     @classmethod
-    def is_me(cls, model: Any):
+    def is_me(cls, model: Model):
 
         if model.format == cls.FORMAT:
             return True
@@ -293,7 +286,7 @@ class ZippedSavedModel(Identifier):
     FORMAT = ModelFormat.ZIPPED_SAVED_MODEL
 
     @classmethod
-    def is_me(cls, model: Any) -> bool:
+    def is_me(cls, model: Model) -> bool:
 
         if model.format == cls.FORMAT:
             return True
@@ -325,7 +318,7 @@ class TFKerasModel(Identifier):
     FORMAT = ModelFormat.TF_KERAS_MODEL
 
     @classmethod
-    def is_me(cls, model: Any):
+    def is_me(cls, model: Model):
 
         if model.format == cls.FORMAT:
             return True
@@ -339,7 +332,7 @@ class TFSession(Identifier):
     FORMAT = ModelFormat.TF_SESSION
 
     @classmethod
-    def is_me(cls, model: Any):
+    def is_me(cls, model: Model):
 
         if model.format == cls.FORMAT:
             return True
@@ -356,7 +349,7 @@ class KerasModel(Identifier):
     FORMAT = ModelFormat.KERAS_MODEL
 
     @classmethod
-    def is_me(cls, model: Any):
+    def is_me(cls, model: Model):
 
         if model.format == cls.FORMAT:
             return True
@@ -370,7 +363,7 @@ class PytorchModel(Identifier):
     FORMAT = ModelFormat.PT_NN_MODULE
 
     @classmethod
-    def is_me(cls, model: Any):
+    def is_me(cls, model: Model):
 
         if model.format == cls.FORMAT:
             return True
@@ -408,4 +401,5 @@ class TensorrtPLAN(Identifier):
         model_path = model.src
         if not os.path.isfile(model_path):
             return False
-        return model_path.endswith(".plan") or model_path.endswith(".engine")
+        return str(model_path).endswith(".plan") or str(model_path).endswith(
+            ".engine")
